@@ -13,9 +13,8 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with MooseFS; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02111-1301, USA
- * or visit http://www.gnu.org/licenses/gpl-2.0.html
+ * along with this program; if not, see
+ * <https://www.gnu.org/licenses/>.
  */
 
 #include <stdio.h>
@@ -1404,6 +1403,10 @@ int check_arch_mode(uint8_t arch_mode) {
 		fprintf(stderr,"Fast arch mode ('F') is mutually exclusive with all other arch modes\n");
 		return -1;
 	}
+	if ((arch_mode & SCLASS_ARCH_MODE_REVERSIBLE) && (arch_mode & (SCLASS_ARCH_MODE_CTIME|SCLASS_ARCH_MODE_MTIME|SCLASS_ARCH_MODE_ATIME))==0) {
+		fprintf(stderr,"Reversible arch mode ('R') needs at least one time flag ('A','M' or 'C')\n");
+		return -1;
+	}
 	return 0;
 }
 
@@ -1558,7 +1561,6 @@ int modifyscexe(int argc,char *argv[]) {
 		return 1;
 	}
 
-
 	if (argc==0) {
 		modifyscusage();
 		return 1;
