@@ -13,9 +13,8 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with MooseFS; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02111-1301, USA
- * or visit http://www.gnu.org/licenses/gpl-2.0.html
+ * along with this program; if not, see
+ * <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1102,6 +1101,12 @@ void changeugid(void) {
 		} else {
 			mfs_log(MFSLOG_SYSLOG,MFSLOG_INFO,"set gid to %d",(int)wrk_gid);
 		}
+		if (setgroups(0, NULL)<0) {
+			mfs_log(MFSLOG_ERRNO_SYSLOG_STDERR,MFSLOG_ERR,"can't clear auxiliary groups");
+			exit(1);
+		} else {
+			mfs_log(MFSLOG_SYSLOG,MFSLOG_INFO,"cleared auxiliary groups");
+		}
 		if (setuid(wrk_uid)<0) {
 			mfs_log(MFSLOG_ERRNO_SYSLOG_STDERR,MFSLOG_ERR,"can't set uid to %d",(int)wrk_uid);
 			exit(1);
